# Changelog

All notable changes to Jnkn.

## Versioning

Jnkn follows [Semantic Versioning](https://semver.org/):

- **MAJOR** — Incompatible API changes
- **MINOR** — New functionality, backwards compatible
- **PATCH** — Bug fixes, backwards compatible

---

## Links

- [GitHub Releases](https://github.com/bordumb/jnkn/releases)
